@@ -5,10 +5,10 @@ use utf8;
 
 package Dist::Zilla::Plugin::Author::Plicease::OSPrereqsNot;
 # ABSTRACT: List prerequisites conditional on operating system
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.61'; # VERSION
 
 use Moose;
-use List::AllUtils 'first';
+use List::Util 'first';
 use namespace::autoclean;
 
 with 'Dist::Zilla::Role::InstallTool', 'Dist::Zilla::Role::MetaProvider';
@@ -145,7 +145,7 @@ Dist::Zilla::Plugin::Author::Plicease::OSPrereqsNot - List prerequisites conditi
 
 =head1 VERSION
 
-version 1.60
+version 1.61
 
 =for Pod::Coverage setup_installer metadata
 
